==> core-react-0.8.0.tgz: package/es/BackToTop/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { scrollTo, currentYPosition } from './scroll';
import Icon from '../Icon';

var BackToTop = /*#__PURE__*/function (_Component) {
  _inherits(BackToTop, _Component);

  function BackToTop(props) {
    var _this;

    _classCallCheck(this, BackToTop);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(BackToTop).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "handleScroll", function () {
      var scrollY = currentYPosition();
      var show = scrollY > _this.props.topDistance;
      var opacity = _this.state.style.opacity;

      if (opacity === 0 && show) {
        _this.setState(_objectSpread({}, _this.state, {
          style: _objectSpread({}, _this.state.style, {
            opacity: 1,
            zIndex: 2000
          })
        }));
      } else if (opacity === 1 && !show) {
        _this.setState(_objectSpread({}, _this.state, {
          style: _objectSpread({}, _this.state.style, {
            opacity: 0,
            zIndex: -1
          })
        }));
      }
    });

    _defineProperty(_assertThisInitialized(_this), "handleHover", function (hover) {
      _this.setState(_objectSpread({}, _this.state, {
        hover: hover
      }));
    });

    _defineProperty(_assertThisInitialized(_this), "handleClickBack", function () {
      var scrollY = currentYPosition();
      scrollTo(0, scrollY / _this.props.speed, _this.props.timing);
    });

    _this.state = {
      style: _objectSpread({}, props.position, {
        position: 'fixed',
        zIndex: 2000,
        paddingBottom: '50%',
        padding: '8px 12px',
        fontSize: props.fontSize,
        textAlign: 'center',
        whiteSpace: 'nowrap',
        width: props.text === '' && !props.icon && "".concat(props.radius * 2, "px"),
        height: props.text === '' && !props.icon && "".concat(props.radius * 2, "px"),
        opacity: 0,
        color: props.color,
        background: props.background,
        border: 'none',
        borderRadius: props.shape === 'round' ? '50%' : '0',
        cursor: 'pointer',
        outline: 'none',
        boxShadow: '0 2px 5px 0 rgba(0,0,0,.26)',
        transition: 'all .5s'
      }),
      hover: false
    };
    _this.handleScroll = _this.handleScroll.bind(_assertThisInitialized(_this));
    return _this;
  }

  _createClass(BackToTop, [{
    key: "componentWillMount",
    value: function componentWillMount() {
      var _this$props = this.props,
          icon = _this$props.icon,
          text = _this$props.text;
      var iconStyle = {
        paddingRight: text !== '' ? '10px' : '0'
      };

      if (icon === '') {
        this.ico = '';
      } else {
        this.ico = React.createElement(Icon, {
          type: icon,
          style: iconStyle
        });
      }
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      window.addEventListener('scroll', this.handleScroll);
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      window.removeEventListener('scroll', this.handleScroll);
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props2 = this.props,
          text = _this$props2.text,
          hover = _this$props2.hover;
      return React.createElement("button", {
        ref: function ref(instance) {
          _this2.btn = instance;
        },
        style: this.state.hover ? _objectSpread({}, this.state.style, {}, hover) : this.state.style,
        onClick: this.handleClickBack,
        onMouseOver: function onMouseOver() {
          return _this2.handleHover(true);
        },
        onMouseOut: function onMouseOut() {
          return _this2.handleHover(false);
        }
      }, this.ico, text);
    }
  }]);

  return BackToTop;
}(Component);

BackToTop.defaultProps = {
  shape: 'default',
  text: '',
  icon: '',
  radius: 0,
  fontSize: '18px',
  position: {
    bottom: '10%',
    right: '5%'
  },
  color: 'white',
  background: 'rgba(0, 0, 0, .5)',
  hover: {
    background: 'rgba(0, 0, 0, .7)'
  },
  topDistance: 200,
  timing: 'linear',
  speed: 100
};
BackToTop.propTypes = {
  /** 按钮形状，默认`default`无圆角， 可选`round` */
  shape: PropTypes.oneOf(['default', 'round']),

  /** 按钮圆角的大小 */
  radius: PropTypes.number,

  /** 按钮中的文字 */
  text: PropTypes.string,

  /** 文字字体大小，默认`18px` */
  fontSize: PropTypes.string,

  /** 按钮的 position, 包括 top, bottom, left, right, 默认`position: {bottom: '10%', right: '5%'}` */
  position: PropTypes.shape({
    top: PropTypes.string,
    bottom: PropTypes.string,
    left: PropTypes.string,
    right: PropTypes.string
  }),

  /** 按钮的图标类型 */
  icon: PropTypes.string,

  /** 按钮文字颜色，默认`white` */
  color: PropTypes.string,

  /** 按钮的背景颜色， 默认`rgba(0, 0, 0, .5)` */
  background: PropTypes.string,

  /** 按钮hover时候的背景颜色， 默认`rgba(0, 0, 0, .7)` */
  hover: PropTypes.object,

  /** 按钮距离顶部的高度，默认`200` */
  topDistance: PropTypes.number,

  /** 按钮出现和消失的动画类型，默认`linear`，此外还有`easeIn/easeOut/easeInOut` */
  timing: PropTypes.oneOf(['linear', 'easeIn', 'easeOut', 'easeInOut']),

  /** 按钮出现和消失的速度，默认`100` */
  speed: PropTypes.number
};
export default BackToTop;

==> core-react-0.8.2.tgz: package/es/BackToTop/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { scrollTo, currentYPosition } from './scroll';
import Icon from '../Icon';

var BackToTop = /*#__PURE__*/function (_Component) {
  _inherits(BackToTop, _Component);

  function BackToTop(props) {
    var _this;

    _classCallCheck(this, BackToTop);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(BackToTop).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "handleScroll", function () {
      var scrollY = currentYPosition();
      var show = scrollY > _this.props.topDistance;
      var opacity = _this.state.style.opacity;

      if (opacity === 0 && show) {
        _this.setState(_objectSpread({}, _this.state, {
          style: _objectSpread({}, _this.state.style, {
            opacity: 1,
            zIndex: 2000
          })
        }));
      } else if (opacity === 1 && !show) {
        _this.setState(_objectSpread({}, _this.state, {
          style: _objectSpread({}, _this.state.style, {
            opacity: 0,
            zIndex: -1
          })
        }));
      }
    });

    _defineProperty(_assertThisInitialized(_this), "handleHover", function (hover) {
      _this.setState(_objectSpread({}, _this.state, {
        hover: hover
      }));
    });

    _defineProperty(_assertThisInitialized(_this), "handleClickBack", function () {
      var scrollY = currentYPosition();
      scrollTo(0, scrollY / _this.props.speed, _this.props.timing);
    });

    _this.state = {
      style: _objectSpread({}, props.position, {
        position: 'fixed',
        zIndex: 2000,
        paddingBottom: '50%',
        padding: '8px 12px',
        fontSize: props.fontSize,
        textAlign: 'center',
        whiteSpace: 'nowrap',
        width: props.text === '' && !props.icon && "".concat(props.radius * 2, "px"),
        height: props.text === '' && !props.icon && "".concat(props.radius * 2, "px"),
        opacity: 0,
        color: props.color,
        background: props.background,
        border: 'none',
        borderRadius: props.shape === 'round' ? '50%' : '0',
        cursor: 'pointer',
        outline: 'none',
        boxShadow: '0 2px 5px 0 rgba(0,0,0,.26)',
        transition: 'all .5s'
      }),
      hover: false
    };
    _this.handleScroll = _this.handleScroll.bind(_assertThisInitialized(_this));
    return _this;
  }

  _createClass(BackToTop, [{
    key: "componentWillMount",
    value: function componentWillMount() {
      var _this$props = this.props,
          icon = _this$props.icon,
          text = _this$props.text;
      var iconStyle = {
        paddingRight: text !== '' ? '10px' : '0'
      };

      if (icon === '') {
        this.ico = '';
      } else {
        this.ico = /*#__PURE__*/React.createElement(Icon, {
          type: icon,
          style: iconStyle
        });
      }
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      window.addEventListener('scroll', this.handleScroll);
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      window.removeEventListener('scroll', this.handleScroll);
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props2 = this.props,
          text = _this$props2.text,
          hover = _this$props2.hover;
      return (/*#__PURE__*/React.createElement("button", {
          ref: function ref(instance) {
            _this2.btn = instance;
          },
          style: this.state.hover ? _objectSpread({}, this.state.style, {}, hover) : this.state.style,
          onClick: this.handleClickBack,
          onMouseOver: function onMouseOver() {
            return _this2.handleHover(true);
          },
          onMouseOut: function onMouseOut() {
            return _this2.handleHover(false);
          }
        }, this.ico, text)
      );
    }
  }]);

  return BackToTop;
}(Component);

BackToTop.defaultProps = {
  shape: 'default',
  text: '',
  icon: '',
  radius: 0,
  fontSize: '18px',
  position: {
    bottom: '10%',
    right: '5%'
  },
  color: 'white',
  background: 'rgba(0, 0, 0, .5)',
  hover: {
    background: 'rgba(0, 0, 0, .7)'
  },
  topDistance: 200,
  timing: 'linear',
  speed: 100
};
BackToTop.propTypes = {
  /** 按钮形状，默认`default`无圆角， 可选`round` */
  shape: PropTypes.oneOf(['default', 'round']),

  /** 按钮圆角的大小 */
  radius: PropTypes.number,

  /** 按钮中的文字 */
  text: PropTypes.string,

  /** 文字字体大小，默认`18px` */
  fontSize: PropTypes.string,

  /** 按钮的 position, 包括 top, bottom, left, right, 默认`position: {bottom: '10%', right: '5%'}` */
  position: PropTypes.shape({
    top: PropTypes.string,
    bottom: PropTypes.string,
    left: PropTypes.string,
    right: PropTypes.string
  }),

  /** 按钮的图标类型 */
  icon: PropTypes.string,

  /** 按钮文字颜色，默认`white` */
  color: PropTypes.string,

  /** 按钮的背景颜色， 默认`rgba(0, 0, 0, .5)` */
  background: PropTypes.string,

  /** 按钮hover时候的背景颜色， 默认`rgba(0, 0, 0, .7)` */
  hover: PropTypes.object,

  /** 按钮距离顶部的高度，默认`200` */
  topDistance: PropTypes.number,

  /** 按钮出现和消失的动画类型，默认`linear`，此外还有`easeIn/easeOut/easeInOut` */
  timing: PropTypes.oneOf(['linear', 'easeIn', 'easeOut', 'easeInOut']),

  /** 按钮出现和消失的速度，默认`100` */
  speed: PropTypes.number
};
export default BackToTop;
